@@ -2,7 +2,7 @@ package Log::Dispatch::Pipe;
 use 5.008001;
 use strict;
 use warnings;
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 use Log::Dispatch 2.00;
 use parent 'Log::Dispatch::Output';
@@ -32,7 +32,7 @@ sub _init {
 sub _open_handle {
     my $self = shift;
 
-    open my $fh, '|' . $self->{output_to}
+    open my $fh, '|-', $self->{output_to}
         or die "Failed opening pipe: $!";
 
     binmode $fh, $self->{binmode}
